@@ -671,13 +671,16 @@ function get_available_views() {
 	  $view['default_size'] : $conf['default_view_graph_size'];
 	$view_parent = 
 	  isset($view['parent']) ? $view['parent'] : NULL;
+	$common_y_axis = 
+	  isset($view['common_y_axis']) ? $view['common_y_axis'] : 0;
 
 	$available_views[] = array ("file_name" => $view_config_file, 
 				    "view_name" => $view['view_name'],
 				    "default_size" => $default_size, 
 				    "items" => $view['items'], 
 				    "view_type" => $view_type,
-				    "parent" => $view_parent);
+				    "parent" => $view_parent,
+				    "common_y_axis" => $common_y_axis);
 	unset($view);
       }
     }
@@ -719,7 +722,7 @@ function get_view_graph_elements($view) {
   switch ( $view['view_type'] ) {
   case "standard":
     // Does view have any items/graphs defined
-    if ( sizeof($view['items']) == 0 ) {
+    if ( count($view['items']) == 0 ) {
       continue;
       // print "No graphs defined for this view. Please add some";
     } else {
@@ -753,10 +756,10 @@ function get_view_graph_elements($view) {
 	    $graph_args_array[] = "gtype=line";
 	  
 	  if (isset($item['upper_limit']))
-	    $graph_args_array[] = "x=" .$item['upper_limit'];
+	    $graph_args_array[] = "x=" . $item['upper_limit'];
 	  
 	  if (isset($item['lower_limit']))
-	    $graph_args_array[] = "n=" .$item['lower_limit'];
+	    $graph_args_array[] = "n=" . $item['lower_limit'];
 	  
 	  if (isset($item['vertical_label']))
 	    $graph_args_array[] = "vl=" . urlencode($item['vertical_label']);
@@ -791,6 +794,7 @@ function get_view_graph_elements($view) {
 	} else if ($item['item_id']) {
 	  $graph_args_array[] = "vn=" . $view['view_name'];
           $graph_args_array[] = "item_id=" . $item['item_id'];
+
 	  $view_elements[] = 
 	    array("graph_args" => join("&", $graph_args_array));
           unset($graph_args_array);
@@ -825,11 +829,11 @@ function get_view_graph_elements($view) {
 	  }
 	  $graph_args_array[] = "c=" . urlencode($cluster);
 
-          if (isset($item['upper_limit']))
-            $graph_args_array[] = "x=" .$item['upper_limit'];
+	  if (isset($item['upper_limit']))
+	    $graph_args_array[] = "x=" . $item['upper_limit'];
 	  
 	  if (isset($item['lower_limit']))
-	    $graph_args_array[] = "n=" .$item['lower_limit'];
+	    $graph_args_array[] = "n=" . $item['lower_limit'];
 	  
 	  if (isset($item['vertical_label']))
 	    $graph_args_array[] = "vl=" . urlencode($item['vertical_label']);
@@ -861,7 +865,7 @@ function get_view_graph_elements($view) {
 	  unset($graph_args_array);
 	}
       } // end of foreach ( $view['items']
-    } // end of if ( sizeof($view['items'])
+    } // end of if ( count($view['items'])
     break;
 
     ///////////////////////////////////////////////////////////////////////////
@@ -1113,7 +1117,7 @@ function build_aggregate_graph_config ($graph_type,
   
   retrieve_metrics_cache();
   
-  $color_count = sizeof($conf['graph_colors']);
+  $color_count = count($conf['graph_colors']);
 
   $graph_config["report_name"]=isset($mreg)  ?  sanitize(implode($mreg))   : NULL;
   $graph_config["title"]=isset($mreg)  ?  sanitize(implode($mreg))   : NULL;
@@ -1132,7 +1136,7 @@ function build_aggregate_graph_config ($graph_type,
         }
       }
     }
-  }
+  } 
 
   sort($host_matches);
 
@@ -1192,7 +1196,7 @@ function build_aggregate_graph_config ($graph_type,
           else
             $label = $host_name;
 
- 	  if (isset($metric_matches) and sizeof($metric_matches_unique) > 1)
+ 	  if (isset($metric_matches) and count($metric_matches_unique) > 1)
             $label .= " $legend";
 	}
 
